.. -*- mode: rst -*-

.. image:: https://travis-ci.org/piti118/iminuit.png?branch=master
   :target: https://travis-ci.org/piti118/iminuit

iminuit
--------

Interactive IPython Friendly Mimizer based on `SEAL Minuit <http://seal.web.cern.ch/seal/work-packages/mathlibs/minuit/release/download.html>`_.
(It's included in the package no need to install it separately)

iminuit is mostly compatible with PyMinuit(with very few exception). Existing
code can be ported to iminuit by just changing the import statement.

Install
-------

::

    python setup.py install

Tutorial
--------

see tutorial.ipynb notebook or tutorial.py if you don't have ipython notebook


Documentation
-------------

http://piti118.github.com/iminuit/
